Stan Math Library: Eigen::internal Namespace Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

Classes
Eigen::internal Namespace Reference

(Expert) Product traits for algorithmic differentiation variables. More...

## Classes
struct | general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor >
struct | general_matrix_vector_product< Index, stan::math::var, RowMajor, ConjugateLhs, stan::math::var, ConjugateRhs >
struct | general_matrix_vector_product< Index, stan::math::var, ColMajor, ConjugateLhs, stan::math::var, ConjugateRhs >
| Override matrix-vector and matrix-matrix products to use more efficient implementation. More...
struct | scalar_product_traits< double, stan::math::var >
| Scalar product traits override for Eigen for automatic gradient variables. More...
struct | scalar_product_traits< stan::math::var, double >
| Scalar product traits override for Eigen for automatic gradient variables. More...
struct | significant_decimals_default_impl< stan::math::fvar< T >, false >
| Implemented this for printing to stream. More...
struct | significant_decimals_default_impl< stan::math::var, false >
| Implemented this for printing to stream. More...

## Detailed Description

(Expert) Product traits for algorithmic differentiation variables.

[ Stan Home Page ] © 2011–2016, Stan Development Team.